#!/usr/bin/env python3
"""
Setup script for PaprWall - for compatibility with older tools.
Main configuration is in pyproject.toml.
"""

from setuptools import setup

if __name__ == "__main__":
    setup()
